***********
Communities
***********

.. automodule:: networkx.algorithms.community
.. currentmodule:: networkx


Bipartitions
------------
.. automodule:: networkx.algorithms.community.kernighan_lin
.. autosummary::
   :toctree: generated/

   kernighan_lin_bisection

K-Clique
--------
.. automodule:: networkx.algorithms.community.kclique
.. autosummary::
   :toctree: generated/

   k_clique_communities

Modularity-based communities
----------------------------
.. automodule:: networkx.algorithms.community.modularity_max
.. autosummary::
   :toctree: generated/
   
   greedy_modularity_communities

Label propagation
-----------------
.. automodule:: networkx.algorithms.community.label_propagation
.. autosummary::
   :toctree: generated/

   asyn_lpa_communities
   label_propagation_communities

Fluid Communities
-----------------
.. automodule:: networkx.algorithms.community.asyn_fluid
.. autosummary::
   :toctree: generated/

   asyn_fluidc

Measuring partitions
--------------------
.. automodule:: networkx.algorithms.community.quality
.. autosummary::
   :toctree: generated/

   coverage
   performance

Partitions via centrality measures
----------------------------------
.. automodule:: networkx.algorithms.community.centrality
.. autosummary::
   :toctree: generated/

   girvan_newman

Validating partitions
---------------------
.. automodule:: networkx.algorithms.community.community_utils
.. autosummary::
   :toctree: generated/

   is_partition
